/* EPSG/GeoTIFF Rev 0.2 Prime Meridian Database */

/* C database for Geotiff include files.   */
/* the macro ValuePair() must be defined   */
/* by the enclosing include file           */

#ifdef INCLUDE_OLD_CODES
#include old_pm.inc
#endif /* OLD Codes */

ValuePair(PM_Greenwich,	8901)
ValuePair(PM_Lisbon,	8902)
ValuePair(PM_Paris,	8903)
ValuePair(PM_Bogota,	8904)
ValuePair(PM_Madrid,	8905)
ValuePair(PM_Rome,	8906)
ValuePair(PM_Bern,	8907)
ValuePair(PM_Jakarta,	8908)
ValuePair(PM_Ferro,	8909)
ValuePair(PM_Brussels,	8910)
ValuePair(PM_Stockholm,	8911)
/* end of list */
